<?php

namespace Lc\ShopBundle\Repository;

use Doctrine\Common\Persistence\ManagerRegistry;
use Doctrine\ORM\EntityManager;
use Doctrine\ORM\QueryBuilder;
use Lc\ShopBundle\Context\GlobalParamInterface;
use Lc\ShopBundle\Context\ProductCategoryInterface;

/**
 * @method ProductCategoryInterface|null find($id, $lockMode = null, $lockVersion = null)
 * @method ProductCategoryInterface|null findOneBy(array $criteria, array $orderBy = null)
 * @method ProductCategoryInterface[]    findAll()
 * @method ProductCategoryInterface[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class ProductCategoryRepository extends BaseRepository
{
        protected $globalParam ;

        public function __construct(EntityManager $entityManager, GlobalParamInterface $globalParam)
        {
                $this->globalParam = $globalParam ;
                parent::__construct($entityManager, ProductCategoryInterface::class);
        }

        public static function adminQueryBuilderForTree(BaseRepository $e): QueryBuilder
        {
                return $e->createQueryBuilder('e')
                        ->where('e.parent is NULL')
                        ->andWhere('e.status >= 0')
                        ->orderBy('e.position', 'ASC');
        }

        public function findAllParents()
        {
                return $this->findByMerchantQuery($this->globalParam->getCurrentMerchant())
                        ->andWhere('e.parent is NULL')
                        ->andWhere('e.status >= 0')
                        ->orderBy('e.position', 'ASC')
                        ->getQuery()
                        ->getResult();
        }

        public function findAllByParent($parentCategory)
        {
                //$query = $this->findByMerchantQuery($this->globalParam->getCurrentMerchant()) ;
                $query = $this->createQueryBuilder('e') ;
                $query->andWhere('e.parent = :idParentCategory')
                        ->setParameter('idParentCategory', $parentCategory->getId());

                return $query->getQuery()->getResult() ;
        }
}
